#!/bin/bash

installed=$(apt list nvidia-docker2 | grep nvidia-docker2)

if ! [[ "$installed" ]]; then
   distribution=$(. /etc/os-release;echo $ID$VERSION_ID) \
        && curl -fsSL https://nvidia.github.io/libnvidia-container/gpgkey | sudo gpg --dearmor -o /usr/share/keyrings/nvidia-container-toolkit-keyring.gpg \
        && curl -s -L https://nvidia.github.io/libnvidia-container/experimental/$distribution/libnvidia-container.list | \
           sed 's#deb https://#deb [signed-by=/usr/share/keyrings/nvidia-container-toolkit-keyring.gpg] https://#g' | \
           sudo tee /etc/apt/sources.list.d/nvidia-container-toolkit.list

  # Install and setup nvidia-docker2
  sudo apt-get update
  sudo apt-get install -y nvidia-docker2
  sudo systemctl restart docker || { echo >&2 "Restart Docker and run the script again"; exit 1; }
fi

# Test runtime
sudo docker run --rm --gpus all nvidia/cuda:11.7.1-base-ubuntu22.04 nvidia-smi || exit 1

echo "Nvidia Container Toolkit installation was successful."