#!/bin/bash

# shellcheck disable=SC2001
cc_version=$(echo "$1" | sed -e 's/\.//g')
cv_versions="86 80 75 72 70 62 61 60 53"

if [[ $cv_versions =~ $cc_version ]]; then
  darknet_tag=gpu-cv-cc$cc_version
else
  echo "Container with given cc_version was not found. Defaulting to generic one."
  darknet_tag=gpu-cv
fi


# Download
docker pull daisukekobayashi/darknet:"$darknet_tag"

# Test
docker run --rm --gpus=all daisukekobayashi/darknet:"$darknet_tag" darknet || exit 1

# Set web app properties for proper functioning
printf "darknet.tag=%s\n" $darknet_tag >> ./local-deploy/config/application.properties || exit 1
printf "acceleration=GPU\n" >> ./local-deploy/config/application.properties || exit 1

echo "YOLO_gpu installation was successful."
