#!/bin/bash

# You can find Compute capability version on https://developer.nvidia.com/cuda-gpus based on your GPU

while [ $# -gt 0 ]; do
    if [[ $1 == "--"* ]]; then
        v="${1/--/}"
        declare "$v"="$2"
        shift
    fi
    shift
done

# System updates
sudo apt update && sudo apt upgrade -y

# For proper access to install files
sudo chown -R "$USER" ./*
sudo chgrp -R "$USER" ./*

# For proper access to docker socket
if [[ $(getent group docker) != *"$USER"* ]]; then
  echo "Adding current user $USER to docker group..."
  sudo groupadd docker
  sudo usermod -aG docker "$USER"
  echo "Please restart terminal and start installation again."
  echo "Prosim restartujte terminal a spusťte instalaci znovu." && exit
fi

# Clear config to make installation idempotent
cat ./local-deploy/config/application.properties.template > ./local-deploy/config/application.properties

if [ "$cc_version" ]; then
  bash ./install-scripts/install-nvidia-docker2.sh || { echo >&2 "Installation of Nvidia Container Toolkit failed."; exit 1; }

  if [[ "$gh_user" && "$gh_token" ]]; then
    echo "$gh_token" | docker login ghcr.io -u "$gh_user" --password-stdin
    bash ./install-scripts/install-unreal.sh || { echo >&2 "Installation of Unreal Engine Container failed."; exit 1; }
  else
    printf "unreal=False\n" >> ./local-deploy/config/application.properties
  fi
  bash ./install-scripts/install-yolo-gpu.sh "$cc_version" || { echo >&2 "Installation of YOLO_GPU container failed."; exit 1; }
else
  bash ./install-scripts/install-yolo-cpu.sh || { echo >&2 "Installation of YOLO_CPU container failed."; exit 1; }
  printf "unreal=False\n" >> ./local-deploy/config/application.properties
fi

docker compose -f ./local-deploy/docker-compose.yaml up --wait || { echo >&2 "Installation of Unreal YOLO failed."; exit 1; }

echo "Installation was successful. You can use web application by opening http://localhost:8181"
echo "Instalace byla uspesna. Muzete zacit pouzivat webovou aplikaci otevrenim http://localhost:8181"
